netapp_ontap.models.fc_interface_recommend_message API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fc_interface_recommend_message`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FcInterfaceRecommendMessageSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FcInterfaceRecommendMessage object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `arguments: List[ErrorArguments] GET`

    The message substitution arguments.

  `code: str GET`

    The message code. Possible messages: ONTAP Error Response Codes | Error Code | Description | | ---------- | ----------- | | 5375959 | Network ports are disabled. | | 5375960 | Network ports are enabled, but not reporting a connected FC fabric. | | 5375961 | The limit for the number of FC network interfaces on a cluster node has been reached. | | 5375962 | The limit for the number of FC network interfaces on a port has been reached. | | 5375963 | An HA pair of cluster nodes has a discrepancy in the presence of FC ports. | | 5375964 | An HA pair of cluster nodes has a discrepancy in support for an FC data protocol. | | 5375965 | An HA pair of cluster nodes cannot be reached from the same FC fabrics. | | 5375966 | A cluster node cannot be reached from all of the FC fabrics from which other cluster nodes with FC interfaces in the SVM can be reached. | | 5375967 | The limit for the number of FC network interfaces on a cluster node has been exceeded. | | 5375968 | The limit for the number of FC network interfaces on an FC port has been exceeded. | | 5375969 | The requested number of network interfaces per FC fabric per cluster node has not been achieved. | | 5375970 | The SVM cannot be reached from all of the FC fabrics to which the cluster is connected. | | 5375971 | The limit for the number of NVMe network interfaces on a cluster node has been exceeded. | | 5375972 | The limit for the number of cluster nodes containing NVMe network interfaces for the SVM has been exceeded. | | 5375973 | The SVM can be reached from a number of FC fabrics other than what is preferred. | Also see the table of common errors in the Response body overview section of this documentation.

    Example: 5375959

  `message: str GET`

    The message text.

    Example: Network ports are disabled.

  `severity: str GET`

    The severity of the message. Message severities are as follows: - `error` - Messages reporting problems that must be corrected before creating the FC network interfaces. - `warning` - Messages indicating issues that need rectifying in order to achieve an optimal configuration. - `informational` - Messages providing relevant information for consideration.

    Valid choices:

    - error
    - warning
    - informational